@@ -13,10 +13,11 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from designateclient import client
+from designateclient.v2.base import V2Controller
+from designateclient.v2 import utils as v2_utils
 
 
-class TLDController(client.Controller):
+class TLDController(V2Controller):
     def create(self, name, description=None):
         data = {
             'name': name,
@@ -32,17 +33,17 @@ class TLDController(client.Controller):
 
         return self._get(url, response_key='tlds')
 
-    def get(self, tld_id):
-        url = '/tlds/%s' % tld_id
+    def get(self, tld):
+        tld = v2_utils.resolve_by_name(self.list, tld)
 
-        return self._get(url)
+        return self._get('/tlds/%s' % tld)
 
-    def update(self, tld_id, values):
-        url = '/tlds/%s' % tld_id
+    def update(self, tld, values):
+        tld = v2_utils.resolve_by_name(self.list, tld)
 
-        return self._patch(url, data=values)
+        return self._patch('/tlds/%s' % tld, data=values)
 
-    def delete(self, tld_id):
-        url = '/tlds/%s' % tld_id
+    def delete(self, tld):
+        tld = v2_utils.resolve_by_name(self.list, tld)
 
-        return self._delete(url)
+        return self._delete('/tlds/%s' % tld)
